@@ -18,17 +18,20 @@ test_that("examples", {
   expect_equal(to_any_case(examples, case = "parsed"),
              cases[["parsed_case"]])
   
-  expect_equal(to_any_case("R.Studio", case = "big_camel", protect = "\\.", postprocess = "-"),
+  expect_equal(to_any_case("R.Studio", case = "big_camel", postprocess = "-"),
                "R.Studio")
   
-  expect_equal(to_any_case("HAMBURGcityGERUsa", case = "parsed", parsingoption = 3),
+  expect_equal(to_any_case("HAMBURGcityGERUsa", case = "parsed", parsing_option = 3),
                "HAMBURG_city_GERU_sa")
   
-  expect_equal(to_any_case("HAMBURGcityGERUsa", case = "parsed", parsingoption = 4),
+  expect_equal(to_any_case("HAMBURGcityGERUsa", case = "parsed", parsing_option = 4),
                "HAMBURG_city_GER_Usa")
   
-  expect_equal(to_any_case("HAMBURGcity", case = "parsed", parsingoption = 5),
+  expect_equal(to_any_case("HAMBURGcity", case = "parsed", parsing_option = 0),
                "HAMBURGcity")
+  
+  expect_equal(to_any_case(c("RSSfeedRSSfeed", "USPassport", "USpassport"), abbreviations = c("RSS", "US")),
+               c("rss_feed_rss_feed", "us_passport", "us_passport"))
 }
 )
 
@@ -150,7 +153,7 @@ test_that("janitor-pkg-tests",{
                               "  leading spaces", "\u20AC", "a\u00E7\u00E3o", "far\u0153", "r.st\u00FCdio:v.1.0.143"),
                             case = "lower_upper"),
                c("spACE", "repeated", "a", "percent", "x", "x_2", "d9", "repeated_2", 
-                 "cant", "hiTHERE", "leadingSPACES", "x_3", "acao", "faroe", "rSTUDIOv10143"
+                 "cant", "hiTHERE", "leadingSPACES", "x_3", "acao", "faroe", "rSTUDIOv1_0_143"
                )
   )
   
@@ -159,7 +162,7 @@ test_that("janitor-pkg-tests",{
                               "  leading spaces", "\u20AC", "a\u00E7\u00E3o", "far\u0153", "r.st\u00FCdio:v.1.0.143"),
                             case = "upper_lower"),
                c("SPace", "REPEATED", "A", "PERCENT", "X", "X_2", "D9", "REPEATED_2", 
-                 "CANT", "HIthere", "LEADINGspaces", "X_3", "ACAO", "FAROE", "RstudioV10143"
+                 "CANT", "HIthere", "LEADINGspaces", "X_3", "ACAO", "FAROE", "RstudioV1_0_143"
                )
   )
   
@@ -172,13 +175,15 @@ test_that("janitor-pkg-tests",{
                  "r_studio_v_1_0_143")
   )
   
-  expect_equal(clean_names3(c("sp ace", "repeated", "a**#@", "%", "#",
-                              "!", "d(!)9", "REPEATED", "can\"'t", "hi_`there`",
-                              "  leading spaces", "\u20AC", "a\u00E7\u00E3o", "far\u0153", "r.st\u00FCdio:v.1.0.143"),
+  expect_equal(clean_names3(c("sp ace", "repeated", "a**#@", "%",
+                              "#", "!", "d(!)9", "REPEATED",
+                              "can\"'t", "hi_`there`", "  leading spaces", "\u20AC",
+                              "a\u00E7\u00E3o", "far\u0153", "r.st\u00FCdio:v.1.0.143"),
                             case = "none"),
-               c("sp_ace", "repeated", "a____", "_percent_", "X_", "X__2", "d___9", 
-                 "REPEATED", "cant", "hi__there_", "leading_spaces", "X__3", "acao", 
-                 "faroe", "r_studio_v_1_0_143")
+               c("sp_ace", "repeated", "a", "percent",
+                 "X", "X_2", "d_9", "REPEATED",
+                 "cant", "hi_there", "leading_spaces", "X_3", 
+                 "acao", "faroe", "r_studio_v_1_0_143")
   )
 })
 
@@ -212,30 +217,29 @@ test_that("complex strings", {
   expect_equal(to_any_case("MERKWUERDIGER-VariablenNAME mit.VIELENMustern_version: 3.7.4",
                            case = "snake",
                            preprocess = "-|:|(?<!\\d)\\.",
-                           protect = "\\.",
                            postprocess = "."),
                "merkwuerdiger.variablen.name.mit.vielen.mustern.version.3.7.4")
   
-  expect_equal(to_any_case("R.Studio", case = "big_camel", protect = "\\."),
+  expect_equal(to_any_case("R.Studio", case = "big_camel"),
                c("R.Studio"))
   
-  expect_equal(to_any_case("R.Studio: v 1.0.143", case = "big_camel", preprocess = "\\.", postprocess = "_", protect = ":"),
+  expect_equal(to_any_case("R.Studio: v 1.0.143", case = "big_camel", preprocess = "\\.", postprocess = "_"),
                "R_Studio:V_1_0_143")
   
-  expect_equal(to_any_case("R.aStudio", case = "snake", protect = "\\.|A", postprocess = "-"), "r.a-studio")
-  expect_equal(to_any_case("R.aStudio", case = "snake", protect = "\\.|a", postprocess = "-"), "r.astudio")
-  expect_equal(to_any_case("R.aStudio", case = "big_camel", protect = "\\.|A", postprocess = "-"), "R.A-Studio")
-  expect_equal(to_any_case("R.aStudio", case = "big_camel", protect = "\\.|a", postprocess = "-"), "R.AStudio")
-  expect_equal(to_any_case("R.aStudio", case = "small_camel", protect = "\\.|A", postprocess = "-"), "r.A-Studio")
-  expect_equal(to_any_case("R.aStudio", case = "small_camel", protect = "\\.|a", postprocess = "-"), "r.AStudio")
-  expect_equal(to_any_case("r.aStudio", protect = "a", postprocess = "-", case = "big_camel"), "R-.AStudio")
+  expect_equal(to_any_case("R.aStudio", case = "snake", postprocess = "-"), "r.a-studio")
+  expect_equal(to_any_case("R.aStudio", case = "snake", postprocess = "-"), "r.a-studio")
+  expect_equal(to_any_case("R.aStudio", case = "big_camel", postprocess = "-"), "R.A-Studio")
+  expect_equal(to_any_case("R.aStudio", case = "big_camel", postprocess = "-"), "R.A-Studio")
+  expect_equal(to_any_case("R.aStudio", case = "small_camel", postprocess = "-"), "r.A-Studio")
+  expect_equal(to_any_case("R.aStudio", case = "small_camel", postprocess = "-"), "r.A-Studio")
+  expect_equal(to_any_case("r.aStudio", postprocess = "-", case = "big_camel"), "R.A-Studio")
   
   expect_equal(to_any_case("rStudio", case = "none", prefix = "rrr."),
                "rrr.rStudio")
   
   expect_equal(to_any_case("Rstudio_STudio_sssTTT", case = "mixed"),
                "Rstudio_S_Tudio_sss_Ttt")
-  expect_equal(to_any_case("Rstudio_STudio_sssTTT", case = "mixed", parsingoption = 2),
+  expect_equal(to_any_case("Rstudio_STudio_sssTTT", case = "mixed", parsing_option = 2),
                "Rstudio_St_udio_sss_Ttt")
   
   expect_equal(to_any_case(names(iris), case = "lower_upper", preprocess = "\\.", postprocess = "-"),
@@ -246,11 +250,11 @@ test_that("complex strings", {
   expect_equal(to_any_case("R.aStudio", case = "upper_lower"),
                "R.aSTUDIO")
   
-  expect_equal(to_any_case("R.aStudio", case = "lower_upper", protect = "\\."),
+  expect_equal(to_any_case("R.aStudio", case = "lower_upper"),
                "r.Astudio")
-  expect_equal(to_any_case("R.aStudio", case = "lower_upper", protect = "\\.|a", postprocess = "-"),
-               "r.Astudio")
-  expect_equal(to_any_case("R.aStudio", case = "lower_upper", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "lower_upper", postprocess = "-"),
+               "r.A-studio")
+  expect_equal(to_any_case("R.aStudio", case = "lower_upper", postprocess = "-"),
                "r.A-studio")
   
   expect_equal(to_any_case("rstudio", case = "all_caps"),
@@ -262,33 +266,33 @@ test_that("complex strings", {
   expect_equal(to_any_case("bla rstudio", case = "lower_camel"),
                "blaRstudio")
   
-  expect_equal(to_any_case("R.aStudio", case = "parsed", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "parsed", postprocess = "-"),
                "R.a-Studio")
-  expect_equal(to_any_case("R.aStudio", case = "small_camel", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "small_camel", postprocess = "-"),
                "r.A-Studio")
-  expect_equal(to_any_case("R.aStudio", case = "big_camel", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "big_camel", postprocess = "-"),
                "R.A-Studio")
-  expect_equal(to_any_case("R.aStudio", case = "screaming_snake", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "screaming_snake", postprocess = "-"),
                "R.A-STUDIO")
-  expect_equal(to_any_case("R.aStudio", case = "lower_upper", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "lower_upper", postprocess = "-"),
                "r.A-studio")
-  expect_equal(to_any_case("R.aStudio", case = "upper_lower", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "upper_lower", postprocess = "-"),
                "R.a-STUDIO")
-  expect_equal(to_any_case("R.aStudio", case = "none", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "none", postprocess = "-"),
                "R.aStudio")
-  expect_equal(to_any_case("R.aStudio", case = "mixed", protect = "\\.|A", postprocess = "-"),
+  expect_equal(to_any_case("R.aStudio", case = "mixed", postprocess = "-"),
                "R.a-Studio")
   
-  expect_equal(to_any_case(character(0), postprocess = "c"), "")
+  expect_equal(to_any_case(character(0), postprocess = "c"), character())
   
-  expect_equal(to_any_case("fdf 1 2", protect = "\\d", case = "big_camel"),
-               "Fdf12")
+  expect_equal(to_any_case("fdf 1 2", case = "big_camel"),
+               "Fdf1_2")
   
-  expect_equal(to_any_case("kleines Ha.schen", "screaming_snake", protect = "a"),
-               "KLEINES_HA._SCHEN")
+  expect_equal(to_any_case("kleines Ha.schen", "screaming_snake"),
+               "KLEINES_HA.SCHEN")
   
-  expect_equal(to_any_case("kleines Ha.schen", "screaming_snake", protect = "Ha"),
-               "KLEINESHA._SCHEN")
+  expect_equal(to_any_case("kleines Ha.schen", "screaming_snake"),
+               "KLEINES_HA.SCHEN")
   
   expect_equal(to_any_case(c("R.aStudio", NA, NA, NA, NA), case = "upper_lower"),
                c("R.aSTUDIO", NA, NA, NA, NA))
@@ -305,11 +309,38 @@ test_that("complex strings", {
   expect_equal(to_any_case("bla.bla", case = "none", preprocess = "\\."),
                "bla_bla")
   
+  expect_equal(to_any_case("blaUSABlaGERBlaZDFBla", abbreviations = c("USA", "GER", "ZDF", "BLA"), case = "mixed"),
+               "bla_USA_Bla_GER_Bla_ZDF_Bla")
+  
+  expect_equal(to_any_case("someUSPeople", abbreviations = "US", case = "mixed", postprocess = " "),
+               "some US People")
+  
   # expect_equal(to_any_case(c(NA, NA, NA), "lower_upper"),
   #              rep(NA_character_, 3))
   # 
   # expect_equal(to_any_case(c(NA, NA, NA), "upper_lower"),
   #              rep(NA_character_, 3))
+  expect_equal(to_any_case("blaBla.bla", case = "big_camel", parsing_option = 5),
+               "BlaBla.bla")
+  
+  expect_equal(to_any_case("bla-bla", case = "upper_camel", parsing_option = 5),
+               "Bla-bla")
+  expect_equal(to_any_case("bla.bla", case = "upper_camel", parsing_option = 5),
+               "Bla.bla")
+  expect_equal(to_any_case("bla.bla", case = "upper_camel"),
+               "Bla.Bla")
+  expect_equal(to_any_case("a_b_c_d", case = "upper_camel"),
+               "ABCD")
+  
+  expect_equal(to_any_case("some11 21 31numbers_11 21 32_With11 11_diffs11 22 d", case = "upper_camel"),
+               "Some11_21_31Numbers11_21_32With11_11Diffs11_22D")
+  expect_equal(to_any_case("some11 21 31numbers_11 21 32_With11 11_diffs11 22 d", case = "lower_camel"),
+               "some11_21_31Numbers11_21_32With11_11Diffs11_22D")
+  expect_equal(to_any_case("some11 21 31numbers_11 21 32_With11 11_diffs11 22 d", case = "upper_lower"),
+               "SOME11_21_31numbers11_21_32WITH11_11diffs11_22D")
+  expect_equal(to_any_case("some11 21 31numbers_11 21 32_With11 11_diffs11 22 d", case = "lower_upper"),
+               "some11_21_31NUMBERS11_21_32with11_11DIFFS11_22d")
+  
 })
 
 
@@ -354,16 +385,16 @@ test_that("parsing cases", {
   expect_equal(to_any_case("RRRStudio", case = "parsed"), 
                "RRR_Studio")
   
-  expect_equal(to_any_case("RRRStudio", case = "parsed", parsingoption = 1), 
+  expect_equal(to_any_case("RRRStudio", case = "parsed", parsing_option = 1), 
                "RRR_Studio")
 
-  expect_equal(to_any_case("RRRStudio", case = "parsed", parsingoption = 2), 
+  expect_equal(to_any_case("RRRStudio", case = "parsed", parsing_option = 2), 
                "RRRS_tudio")
   
-  expect_equal(check_design_rule("RRRStudio", parsingoption = 1),
+  expect_equal(check_design_rule("RRRStudio", parsing_option = 1),
                TRUE)
   
-  expect_equal(check_design_rule("RRRStudio", parsingoption = 2),
+  expect_equal(check_design_rule("RRRStudio", parsing_option = 2),
                TRUE)
   })
 
@@ -387,19 +418,18 @@ test_that("expand.grid", {
   expect_equal(purrrlyr::invoke_rows(snakecase::to_any_case, dat,
                      preprocess = NULL,
                      postprocess = NULL,
-                     protect = NULL,
                      .collate = "cols",
                      .to = "output") %>% .$output, #%>% dput
                c(NA, "", "s_na_k_er", "SNAKE_SNAKE_CASE", "snake_Snak_E_Case", 
                  "SNAKE_snak_E_case", "ss_R_Rss", "ss_RRRR", "this_Is_Some_Camel_Case", 
-                 "this_._text", "final_count", "Bob_Dylan_USA", "Mikhail_Gorbachev_USSR", 
+                 "this.text", "final_count", "Bob_Dylan_USA", "Mikhail_Gorbachev_USSR", 
                  "Helpful_Stack_Overflow_People", "Im_A_Tall_Drink_Of_Water", 
-                 "ICU_Days", "Sex_Code", "MAX_of_MLD", "Age_._Group", NA, "", 
+                 "ICU_Days", "Sex_Code", "MAX_of_MLD", "Age.Group", NA, "", 
                  "s_na_k_er", "snake_snake_case", "snake_snak_e_case", "snake_snak_e_case", 
-                 "ss_r_rss", "ss_rrrr", "this_is_some_camel_case", "this_._text", 
+                 "ss_r_rss", "ss_rrrr", "this_is_some_camel_case", "this.text", 
                  "final_count", "bob_dylan_usa", "mikhail_gorbachev_ussr", "helpful_stack_overflow_people", 
                  "im_a_tall_drink_of_water", "icu_days", "sex_code", "max_of_mld", 
-                 "age_._group", NA, "", "sNaKEr", "snakeSnakeCase", "snakeSnakECase", 
+                 "age.group", NA, "", "sNaKEr", "snakeSnakeCase", "snakeSnakECase", 
                  "snakeSnakECase", "ssRRss", "ssRrrr", "thisIsSomeCamelCase", 
                  "this.Text", "finalCount", "bobDylanUsa", "mikhailGorbachevUssr", 
                  "helpfulStackOverflowPeople", "imATallDrinkOfWater", "icuDays", 
@@ -409,19 +439,19 @@ test_that("expand.grid", {
                  "HelpfulStackOverflowPeople", "ImATallDrinkOfWater", "IcuDays", 
                  "SexCode", "MaxOfMld", "Age.Group", NA, "", "S_NA_K_ER", "SNAKE_SNAKE_CASE", 
                  "SNAKE_SNAK_E_CASE", "SNAKE_SNAK_E_CASE", "SS_R_RSS", "SS_RRRR", 
-                 "THIS_IS_SOME_CAMEL_CASE", "THIS_._TEXT", "FINAL_COUNT", "BOB_DYLAN_USA", 
+                 "THIS_IS_SOME_CAMEL_CASE", "THIS.TEXT", "FINAL_COUNT", "BOB_DYLAN_USA", 
                  "MIKHAIL_GORBACHEV_USSR", "HELPFUL_STACK_OVERFLOW_PEOPLE", "IM_A_TALL_DRINK_OF_WATER", 
-                 "ICU_DAYS", "SEX_CODE", "MAX_OF_MLD", "AGE_._GROUP", NA, ".end", 
+                 "ICU_DAYS", "SEX_CODE", "MAX_OF_MLD", "AGE.GROUP", NA, ".end", 
                  "s_na_k_er.end", "SNAKE_SNAKE_CASE.end", "snake_Snak_E_Case.end", 
                  "SNAKE_snak_E_case.end", "ss_R_Rss.end", "ss_RRRR.end", "this_Is_Some_Camel_Case.end", 
-                 "this_._text.end", "final_count.end", "Bob_Dylan_USA.end", "Mikhail_Gorbachev_USSR.end", 
+                 "this.text.end", "final_count.end", "Bob_Dylan_USA.end", "Mikhail_Gorbachev_USSR.end", 
                  "Helpful_Stack_Overflow_People.end", "Im_A_Tall_Drink_Of_Water.end", 
-                 "ICU_Days.end", "Sex_Code.end", "MAX_of_MLD.end", "Age_._Group.end", 
+                 "ICU_Days.end", "Sex_Code.end", "MAX_of_MLD.end", "Age.Group.end", 
                  NA, ".end", "s_na_k_er.end", "snake_snake_case.end", "snake_snak_e_case.end", 
                  "snake_snak_e_case.end", "ss_r_rss.end", "ss_rrrr.end", "this_is_some_camel_case.end", 
-                 "this_._text.end", "final_count.end", "bob_dylan_usa.end", "mikhail_gorbachev_ussr.end", 
+                 "this.text.end", "final_count.end", "bob_dylan_usa.end", "mikhail_gorbachev_ussr.end", 
                  "helpful_stack_overflow_people.end", "im_a_tall_drink_of_water.end", 
-                 "icu_days.end", "sex_code.end", "max_of_mld.end", "age_._group.end", 
+                 "icu_days.end", "sex_code.end", "max_of_mld.end", "age.group.end", 
                  NA, ".end", "sNaKEr.end", "snakeSnakeCase.end", "snakeSnakECase.end", 
                  "snakeSnakECase.end", "ssRRss.end", "ssRrrr.end", "thisIsSomeCamelCase.end", 
                  "this.Text.end", "finalCount.end", "bobDylanUsa.end", "mikhailGorbachevUssr.end", 
@@ -434,21 +464,21 @@ test_that("expand.grid", {
                  "IcuDays.end", "SexCode.end", "MaxOfMld.end", "Age.Group.end", 
                  NA, ".end", "S_NA_K_ER.end", "SNAKE_SNAKE_CASE.end", "SNAKE_SNAK_E_CASE.end", 
                  "SNAKE_SNAK_E_CASE.end", "SS_R_RSS.end", "SS_RRRR.end", "THIS_IS_SOME_CAMEL_CASE.end", 
-                 "THIS_._TEXT.end", "FINAL_COUNT.end", "BOB_DYLAN_USA.end", "MIKHAIL_GORBACHEV_USSR.end", 
+                 "THIS.TEXT.end", "FINAL_COUNT.end", "BOB_DYLAN_USA.end", "MIKHAIL_GORBACHEV_USSR.end", 
                  "HELPFUL_STACK_OVERFLOW_PEOPLE.end", "IM_A_TALL_DRINK_OF_WATER.end", 
-                 "ICU_DAYS.end", "SEX_CODE.end", "MAX_OF_MLD.end", "AGE_._GROUP.end", 
+                 "ICU_DAYS.end", "SEX_CODE.end", "MAX_OF_MLD.end", "AGE.GROUP.end", 
                  NA, "start.", "start.s_na_k_er", "start.SNAKE_SNAKE_CASE", "start.snake_Snak_E_Case", 
                  "start.SNAKE_snak_E_case", "start.ss_R_Rss", "start.ss_RRRR", 
-                 "start.this_Is_Some_Camel_Case", "start.this_._text", "start.final_count", 
+                 "start.this_Is_Some_Camel_Case", "start.this.text", "start.final_count", 
                  "start.Bob_Dylan_USA", "start.Mikhail_Gorbachev_USSR", "start.Helpful_Stack_Overflow_People", 
                  "start.Im_A_Tall_Drink_Of_Water", "start.ICU_Days", "start.Sex_Code", 
-                 "start.MAX_of_MLD", "start.Age_._Group", NA, "start.", "start.s_na_k_er", 
+                 "start.MAX_of_MLD", "start.Age.Group", NA, "start.", "start.s_na_k_er", 
                  "start.snake_snake_case", "start.snake_snak_e_case", "start.snake_snak_e_case", 
                  "start.ss_r_rss", "start.ss_rrrr", "start.this_is_some_camel_case", 
-                 "start.this_._text", "start.final_count", "start.bob_dylan_usa", 
+                 "start.this.text", "start.final_count", "start.bob_dylan_usa", 
                  "start.mikhail_gorbachev_ussr", "start.helpful_stack_overflow_people", 
                  "start.im_a_tall_drink_of_water", "start.icu_days", "start.sex_code", 
-                 "start.max_of_mld", "start.age_._group", NA, "start.", "start.sNaKEr", 
+                 "start.max_of_mld", "start.age.group", NA, "start.", "start.sNaKEr", 
                  "start.snakeSnakeCase", "start.snakeSnakECase", "start.snakeSnakECase", 
                  "start.ssRRss", "start.ssRrrr", "start.thisIsSomeCamelCase", 
                  "start.this.Text", "start.finalCount", "start.bobDylanUsa", "start.mikhailGorbachevUssr", 
@@ -461,24 +491,24 @@ test_that("expand.grid", {
                  "start.IcuDays", "start.SexCode", "start.MaxOfMld", "start.Age.Group", 
                  NA, "start.", "start.S_NA_K_ER", "start.SNAKE_SNAKE_CASE", "start.SNAKE_SNAK_E_CASE", 
                  "start.SNAKE_SNAK_E_CASE", "start.SS_R_RSS", "start.SS_RRRR", 
-                 "start.THIS_IS_SOME_CAMEL_CASE", "start.THIS_._TEXT", "start.FINAL_COUNT", 
+                 "start.THIS_IS_SOME_CAMEL_CASE", "start.THIS.TEXT", "start.FINAL_COUNT", 
                  "start.BOB_DYLAN_USA", "start.MIKHAIL_GORBACHEV_USSR", "start.HELPFUL_STACK_OVERFLOW_PEOPLE", 
                  "start.IM_A_TALL_DRINK_OF_WATER", "start.ICU_DAYS", "start.SEX_CODE", 
-                 "start.MAX_OF_MLD", "start.AGE_._GROUP", NA, "start..end", "start.s_na_k_er.end", 
+                 "start.MAX_OF_MLD", "start.AGE.GROUP", NA, "start..end", "start.s_na_k_er.end", 
                  "start.SNAKE_SNAKE_CASE.end", "start.snake_Snak_E_Case.end", 
                  "start.SNAKE_snak_E_case.end", "start.ss_R_Rss.end", "start.ss_RRRR.end", 
-                 "start.this_Is_Some_Camel_Case.end", "start.this_._text.end", 
+                 "start.this_Is_Some_Camel_Case.end", "start.this.text.end", 
                  "start.final_count.end", "start.Bob_Dylan_USA.end", "start.Mikhail_Gorbachev_USSR.end", 
                  "start.Helpful_Stack_Overflow_People.end", "start.Im_A_Tall_Drink_Of_Water.end", 
                  "start.ICU_Days.end", "start.Sex_Code.end", "start.MAX_of_MLD.end", 
-                 "start.Age_._Group.end", NA, "start..end", "start.s_na_k_er.end", 
+                 "start.Age.Group.end", NA, "start..end", "start.s_na_k_er.end", 
                  "start.snake_snake_case.end", "start.snake_snak_e_case.end", 
                  "start.snake_snak_e_case.end", "start.ss_r_rss.end", "start.ss_rrrr.end", 
-                 "start.this_is_some_camel_case.end", "start.this_._text.end", 
+                 "start.this_is_some_camel_case.end", "start.this.text.end", 
                  "start.final_count.end", "start.bob_dylan_usa.end", "start.mikhail_gorbachev_ussr.end", 
                  "start.helpful_stack_overflow_people.end", "start.im_a_tall_drink_of_water.end", 
                  "start.icu_days.end", "start.sex_code.end", "start.max_of_mld.end", 
-                 "start.age_._group.end", NA, "start..end", "start.sNaKEr.end", 
+                 "start.age.group.end", NA, "start..end", "start.sNaKEr.end", 
                  "start.snakeSnakeCase.end", "start.snakeSnakECase.end", "start.snakeSnakECase.end", 
                  "start.ssRRss.end", "start.ssRrrr.end", "start.thisIsSomeCamelCase.end", 
                  "start.this.Text.end", "start.finalCount.end", "start.bobDylanUsa.end", 
@@ -493,20 +523,20 @@ test_that("expand.grid", {
                  "start.MaxOfMld.end", "start.Age.Group.end", NA, "start..end", 
                  "start.S_NA_K_ER.end", "start.SNAKE_SNAKE_CASE.end", "start.SNAKE_SNAK_E_CASE.end", 
                  "start.SNAKE_SNAK_E_CASE.end", "start.SS_R_RSS.end", "start.SS_RRRR.end", 
-                 "start.THIS_IS_SOME_CAMEL_CASE.end", "start.THIS_._TEXT.end", 
+                 "start.THIS_IS_SOME_CAMEL_CASE.end", "start.THIS.TEXT.end", 
                  "start.FINAL_COUNT.end", "start.BOB_DYLAN_USA.end", "start.MIKHAIL_GORBACHEV_USSR.end", 
                  "start.HELPFUL_STACK_OVERFLOW_PEOPLE.end", "start.IM_A_TALL_DRINK_OF_WATER.end", 
                  "start.ICU_DAYS.end", "start.SEX_CODE.end", "start.MAX_OF_MLD.end", 
-                 "start.AGE_._GROUP.end", NA, "", "s_na_k_er", "SNAKE_SNAKE_CASE", 
+                 "start.AGE.GROUP.end", NA, "", "s_na_k_er", "SNAKE_SNAKE_CASE", 
                  "snake_Snak_E_Case", "SNAKE_snak_E_case", "ss_R_Rss", "ss_RRRR", 
-                 "this_Is_Some_Camel_Case", "this_._text", "final_count", "Bob_Dylan_USA", 
+                 "this_Is_Some_Camel_Case", "this.text", "final_count", "Bob_Dylan_USA", 
                  "Mikhail_Gorbachev_USSR", "Helpful_Stack_Overflow_People", "Im_A_Tall_Drink_Of_Water", 
-                 "ICU_Days", "Sex_Code", "MAX_of_MLD", "Age_._Group", NA, "", 
+                 "ICU_Days", "Sex_Code", "MAX_of_MLD", "Age.Group", NA, "", 
                  "s_na_k_er", "snake_snake_case", "snake_snak_e_case", "snake_snak_e_case", 
-                 "ss_r_rss", "ss_rrrr", "this_is_some_camel_case", "this_._text", 
+                 "ss_r_rss", "ss_rrrr", "this_is_some_camel_case", "this.text", 
                  "final_count", "bob_dylan_usa", "mikhail_gorbachev_ussr", "helpful_stack_overflow_people", 
                  "im_a_tall_drink_of_water", "icu_days", "sex_code", "max_of_mld", 
-                 "age_._group", NA, "", "sNaKEr", "snakeSnakeCase", "snakeSnakECase", 
+                 "age.group", NA, "", "sNaKEr", "snakeSnakeCase", "snakeSnakECase", 
                  "snakeSnakECase", "ssRRss", "ssRrrr", "thisIsSomeCamelCase", 
                  "this.Text", "finalCount", "bobDylanUsa", "mikhailGorbachevUssr", 
                  "helpfulStackOverflowPeople", "imATallDrinkOfWater", "icuDays", 
@@ -516,19 +546,19 @@ test_that("expand.grid", {
                  "HelpfulStackOverflowPeople", "ImATallDrinkOfWater", "IcuDays", 
                  "SexCode", "MaxOfMld", "Age.Group", NA, "", "S_NA_K_ER", "SNAKE_SNAKE_CASE", 
                  "SNAKE_SNAK_E_CASE", "SNAKE_SNAK_E_CASE", "SS_R_RSS", "SS_RRRR", 
-                 "THIS_IS_SOME_CAMEL_CASE", "THIS_._TEXT", "FINAL_COUNT", "BOB_DYLAN_USA", 
+                 "THIS_IS_SOME_CAMEL_CASE", "THIS.TEXT", "FINAL_COUNT", "BOB_DYLAN_USA", 
                  "MIKHAIL_GORBACHEV_USSR", "HELPFUL_STACK_OVERFLOW_PEOPLE", "IM_A_TALL_DRINK_OF_WATER", 
-                 "ICU_DAYS", "SEX_CODE", "MAX_OF_MLD", "AGE_._GROUP", NA, ".end", 
+                 "ICU_DAYS", "SEX_CODE", "MAX_OF_MLD", "AGE.GROUP", NA, ".end", 
                  "s_na_k_er.end", "SNAKE_SNAKE_CASE.end", "snake_Snak_E_Case.end", 
                  "SNAKE_snak_E_case.end", "ss_R_Rss.end", "ss_RRRR.end", "this_Is_Some_Camel_Case.end", 
-                 "this_._text.end", "final_count.end", "Bob_Dylan_USA.end", "Mikhail_Gorbachev_USSR.end", 
+                 "this.text.end", "final_count.end", "Bob_Dylan_USA.end", "Mikhail_Gorbachev_USSR.end", 
                  "Helpful_Stack_Overflow_People.end", "Im_A_Tall_Drink_Of_Water.end", 
-                 "ICU_Days.end", "Sex_Code.end", "MAX_of_MLD.end", "Age_._Group.end", 
+                 "ICU_Days.end", "Sex_Code.end", "MAX_of_MLD.end", "Age.Group.end", 
                  NA, ".end", "s_na_k_er.end", "snake_snake_case.end", "snake_snak_e_case.end", 
                  "snake_snak_e_case.end", "ss_r_rss.end", "ss_rrrr.end", "this_is_some_camel_case.end", 
-                 "this_._text.end", "final_count.end", "bob_dylan_usa.end", "mikhail_gorbachev_ussr.end", 
+                 "this.text.end", "final_count.end", "bob_dylan_usa.end", "mikhail_gorbachev_ussr.end", 
                  "helpful_stack_overflow_people.end", "im_a_tall_drink_of_water.end", 
-                 "icu_days.end", "sex_code.end", "max_of_mld.end", "age_._group.end", 
+                 "icu_days.end", "sex_code.end", "max_of_mld.end", "age.group.end", 
                  NA, ".end", "sNaKEr.end", "snakeSnakeCase.end", "snakeSnakECase.end", 
                  "snakeSnakECase.end", "ssRRss.end", "ssRrrr.end", "thisIsSomeCamelCase.end", 
                  "this.Text.end", "finalCount.end", "bobDylanUsa.end", "mikhailGorbachevUssr.end", 
@@ -541,21 +571,21 @@ test_that("expand.grid", {
                  "IcuDays.end", "SexCode.end", "MaxOfMld.end", "Age.Group.end", 
                  NA, ".end", "S_NA_K_ER.end", "SNAKE_SNAKE_CASE.end", "SNAKE_SNAK_E_CASE.end", 
                  "SNAKE_SNAK_E_CASE.end", "SS_R_RSS.end", "SS_RRRR.end", "THIS_IS_SOME_CAMEL_CASE.end", 
-                 "THIS_._TEXT.end", "FINAL_COUNT.end", "BOB_DYLAN_USA.end", "MIKHAIL_GORBACHEV_USSR.end", 
+                 "THIS.TEXT.end", "FINAL_COUNT.end", "BOB_DYLAN_USA.end", "MIKHAIL_GORBACHEV_USSR.end", 
                  "HELPFUL_STACK_OVERFLOW_PEOPLE.end", "IM_A_TALL_DRINK_OF_WATER.end", 
-                 "ICU_DAYS.end", "SEX_CODE.end", "MAX_OF_MLD.end", "AGE_._GROUP.end", 
+                 "ICU_DAYS.end", "SEX_CODE.end", "MAX_OF_MLD.end", "AGE.GROUP.end", 
                  NA, "start.", "start.s_na_k_er", "start.SNAKE_SNAKE_CASE", "start.snake_Snak_E_Case", 
                  "start.SNAKE_snak_E_case", "start.ss_R_Rss", "start.ss_RRRR", 
-                 "start.this_Is_Some_Camel_Case", "start.this_._text", "start.final_count", 
+                 "start.this_Is_Some_Camel_Case", "start.this.text", "start.final_count", 
                  "start.Bob_Dylan_USA", "start.Mikhail_Gorbachev_USSR", "start.Helpful_Stack_Overflow_People", 
                  "start.Im_A_Tall_Drink_Of_Water", "start.ICU_Days", "start.Sex_Code", 
-                 "start.MAX_of_MLD", "start.Age_._Group", NA, "start.", "start.s_na_k_er", 
+                 "start.MAX_of_MLD", "start.Age.Group", NA, "start.", "start.s_na_k_er", 
                  "start.snake_snake_case", "start.snake_snak_e_case", "start.snake_snak_e_case", 
                  "start.ss_r_rss", "start.ss_rrrr", "start.this_is_some_camel_case", 
-                 "start.this_._text", "start.final_count", "start.bob_dylan_usa", 
+                 "start.this.text", "start.final_count", "start.bob_dylan_usa", 
                  "start.mikhail_gorbachev_ussr", "start.helpful_stack_overflow_people", 
                  "start.im_a_tall_drink_of_water", "start.icu_days", "start.sex_code", 
-                 "start.max_of_mld", "start.age_._group", NA, "start.", "start.sNaKEr", 
+                 "start.max_of_mld", "start.age.group", NA, "start.", "start.sNaKEr", 
                  "start.snakeSnakeCase", "start.snakeSnakECase", "start.snakeSnakECase", 
                  "start.ssRRss", "start.ssRrrr", "start.thisIsSomeCamelCase", 
                  "start.this.Text", "start.finalCount", "start.bobDylanUsa", "start.mikhailGorbachevUssr", 
@@ -568,24 +598,24 @@ test_that("expand.grid", {
                  "start.IcuDays", "start.SexCode", "start.MaxOfMld", "start.Age.Group", 
                  NA, "start.", "start.S_NA_K_ER", "start.SNAKE_SNAKE_CASE", "start.SNAKE_SNAK_E_CASE", 
                  "start.SNAKE_SNAK_E_CASE", "start.SS_R_RSS", "start.SS_RRRR", 
-                 "start.THIS_IS_SOME_CAMEL_CASE", "start.THIS_._TEXT", "start.FINAL_COUNT", 
+                 "start.THIS_IS_SOME_CAMEL_CASE", "start.THIS.TEXT", "start.FINAL_COUNT", 
                  "start.BOB_DYLAN_USA", "start.MIKHAIL_GORBACHEV_USSR", "start.HELPFUL_STACK_OVERFLOW_PEOPLE", 
                  "start.IM_A_TALL_DRINK_OF_WATER", "start.ICU_DAYS", "start.SEX_CODE", 
-                 "start.MAX_OF_MLD", "start.AGE_._GROUP", NA, "start..end", "start.s_na_k_er.end", 
+                 "start.MAX_OF_MLD", "start.AGE.GROUP", NA, "start..end", "start.s_na_k_er.end", 
                  "start.SNAKE_SNAKE_CASE.end", "start.snake_Snak_E_Case.end", 
                  "start.SNAKE_snak_E_case.end", "start.ss_R_Rss.end", "start.ss_RRRR.end", 
-                 "start.this_Is_Some_Camel_Case.end", "start.this_._text.end", 
+                 "start.this_Is_Some_Camel_Case.end", "start.this.text.end", 
                  "start.final_count.end", "start.Bob_Dylan_USA.end", "start.Mikhail_Gorbachev_USSR.end", 
                  "start.Helpful_Stack_Overflow_People.end", "start.Im_A_Tall_Drink_Of_Water.end", 
                  "start.ICU_Days.end", "start.Sex_Code.end", "start.MAX_of_MLD.end", 
-                 "start.Age_._Group.end", NA, "start..end", "start.s_na_k_er.end", 
+                 "start.Age.Group.end", NA, "start..end", "start.s_na_k_er.end", 
                  "start.snake_snake_case.end", "start.snake_snak_e_case.end", 
                  "start.snake_snak_e_case.end", "start.ss_r_rss.end", "start.ss_rrrr.end", 
-                 "start.this_is_some_camel_case.end", "start.this_._text.end", 
+                 "start.this_is_some_camel_case.end", "start.this.text.end", 
                  "start.final_count.end", "start.bob_dylan_usa.end", "start.mikhail_gorbachev_ussr.end", 
                  "start.helpful_stack_overflow_people.end", "start.im_a_tall_drink_of_water.end", 
                  "start.icu_days.end", "start.sex_code.end", "start.max_of_mld.end", 
-                 "start.age_._group.end", NA, "start..end", "start.sNaKEr.end", 
+                 "start.age.group.end", NA, "start..end", "start.sNaKEr.end", 
                  "start.snakeSnakeCase.end", "start.snakeSnakECase.end", "start.snakeSnakECase.end", 
                  "start.ssRRss.end", "start.ssRrrr.end", "start.thisIsSomeCamelCase.end", 
                  "start.this.Text.end", "start.finalCount.end", "start.bobDylanUsa.end", 
@@ -600,10 +630,10 @@ test_that("expand.grid", {
                  "start.MaxOfMld.end", "start.Age.Group.end", NA, "start..end", 
                  "start.S_NA_K_ER.end", "start.SNAKE_SNAKE_CASE.end", "start.SNAKE_SNAK_E_CASE.end", 
                  "start.SNAKE_SNAK_E_CASE.end", "start.SS_R_RSS.end", "start.SS_RRRR.end", 
-                 "start.THIS_IS_SOME_CAMEL_CASE.end", "start.THIS_._TEXT.end", 
+                 "start.THIS_IS_SOME_CAMEL_CASE.end", "start.THIS.TEXT.end", 
                  "start.FINAL_COUNT.end", "start.BOB_DYLAN_USA.end", "start.MIKHAIL_GORBACHEV_USSR.end", 
                  "start.HELPFUL_STACK_OVERFLOW_PEOPLE.end", "start.IM_A_TALL_DRINK_OF_WATER.end", 
                  "start.ICU_DAYS.end", "start.SEX_CODE.end", "start.MAX_OF_MLD.end", 
-                 "start.AGE_._GROUP.end"))
+                 "start.AGE.GROUP.end"))
   }
 )
\ No newline at end of file
