@@ -22,4 +22,14 @@ test_that("rules",{
   
   expect_equal(to_parsed_case(to_screaming_snake_case(examples)),
                to_screaming_snake_case(examples)) 
+})
+
+test_that("preserve-name-attribute",{
+  labs <- c(a = "abcDEF", b = "bbccEE", c = "TeESt it")
+  
+  expect_equal(
+    to_parsed_case(labs),
+    structure(c("abc_DEF", "bbcc_EE", "Te_E_St_it"), .Names = c("a", 
+                                                                "b", "c"))
+  )
 })
\ No newline at end of file
